### Empezar

PDFMathTranslate es una potente herramienta de traducción de PDF. Puedes instalar y empezar a usar esta herramienta de varias formas.

---

### Instalación

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Recomendado para Windows</small>  
2. [**Docker**](./INSTALLATION_docker.md) <small>Recomendado para Linux</small>  
3. [**uv** (un gestor de paquetes de Python)](./INSTALLATION_uv.md) <small>Recomendado para macOS</small>

---

### Uso

1. [Usando **WebUI**](./USAGE_webui.md)
2. [Usando **Zotero Plugin**](https://github.com/guaguastandup/zotero-pdf2zh) (Programa de terceros)
3. [Usando **Línea de comandos**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>